<?php
/*
Plugin Name: Search Overview (EasyToolsWP)
Description: Admin subpage and dashboard widget for recent and top searches.
Version: 1.5.2
Author: EasyToolsWP
*/

// Hook for adding admin page
add_action('admin_menu', 'search_overview_menu');

function search_overview_menu() {
    add_menu_page('Search Overview', 'Search Overview', 'manage_options', 'search-overview', 'search_overview_page');
}

// Pagination setup
function search_pagination($total, $current_page, $per_page) {
    $total_pages = ceil($total / $per_page);
    
    if ($total_pages > 1) {
        echo '<div class="tablenav"><div class="tablenav-pages">';
        for ($i = 1; $i <= $total_pages; $i++) {
            if ($i == $current_page) {
                echo "<span class='page-numbers current'>$i</span>";
            } else {
                echo "<a class='page-numbers' href='?page=search-overview&paged=$i'>$i</a>";
            }
        }
        echo '</div></div>';
    }
}

// Function to display the admin page content with pagination and positioning
function search_overview_page() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'searches';

    // Number of results per page
    $per_page = 50;
    $current_page = isset($_GET['paged']) ? (int)$_GET['paged'] : 1;
    $offset = ($current_page - 1) * $per_page;

    // Handle form submission for clearing the table
    if (isset($_POST['clear_table']) && check_admin_referer('clear_table_action', 'clear_table_nonce')) {
        $wpdb->query("TRUNCATE TABLE $table_name");
        echo '<div class="updated notice"><p>Table cleared successfully.</p></div>';
    }

    ?>
    <div class="wrap">
        <h1>Search Overview</h1>
        <form method="get" action="">
            <label for="start-date">Start Date:</label>
            <input type="date" id="start-date" name="start-date">
            <label for="end-date">End Date:</label>
            <input type="date" id="end-date" name="end-date">
            <input type="submit" value="Filter">
        </form>

        <h2>Search Data</h2>
        <table class="widefat fixed">
            <thead>
                <tr>
                    <th>Search Query</th>
                    <th>Search Count</th>
                    <th>Last Search Date</th>
                </tr>
            </thead>
            <tbody>
                <?php
                // Get the total number of searches
                $total_searches = $wpdb->get_var("SELECT COUNT(DISTINCT query) FROM $table_name");

                // Fetch paginated search data
                $results = $wpdb->get_results($wpdb->prepare("
                    SELECT query, COUNT(query) AS search_count, MAX(date) AS last_search 
                    FROM $table_name 
                    GROUP BY query 
                    ORDER BY search_count DESC 
                    LIMIT %d OFFSET %d
                ", $per_page, $offset));

                if ($results) {
                    $row_num = $offset + 1; // Start numbering from the correct offset
                    foreach ($results as $search) {
                        echo "<tr>";
                        echo "<td>{$row_num}. {$search->query}</td>";
                        echo "<td>{$search->search_count}</td>";
                        echo "<td>{$search->last_search}</td>";
                        echo "</tr>";
                        $row_num++;
                    }
                } else {
                    echo "<tr><td colspan='3'>No searches found.</td></tr>";
                }
                ?>
            </tbody>
        </table>

        <?php
        // Display pagination
        search_pagination($total_searches, $current_page, $per_page);
        ?>

        <div style="text-align: right; margin-top: 20px;">
            <form method="post" action="">
                <?php wp_nonce_field('clear_table_action', 'clear_table_nonce'); ?>
                <input type="submit" name="clear_table" value="Clear Table" class="button button-primary" onclick="return confirm('Are you sure you want to clear the table?');">
            </form>
        </div>
    </div>
    <?php
}

// Hook to add the dashboard widget
add_action('wp_dashboard_setup', 'search_dashboard_widget');

function search_dashboard_widget() {
    wp_add_dashboard_widget('search_overview_dashboard', 'Search Overview', 'search_overview_dashboard_display');
}

function search_overview_dashboard_display() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'searches';
    ?>
    <div class="tabs">
        <ul class="tab-links">
            <li class="active"><a href="#tab1">Recent Searches</a></li>
            <li><a href="#tab2">Top Searches</a></li>
        </ul>

        <div class="tab-content">
            <div id="tab1" class="tab active">
                <h3>Recent Searches</h3>
                <ul class="search-list">
                    <?php
                    // Display recent searches (last 5 unique queries)
                    $recent_searches = $wpdb->get_results("
                        SELECT query, MAX(date) AS last_search 
                        FROM $table_name 
                        GROUP BY query 
                        ORDER BY last_search DESC 
                        LIMIT 5
                    ");

                    if ($recent_searches) {
                        $i = 1;
                        foreach ($recent_searches as $search) {
                            echo "<li>{$i}. {$search->query} <span class='date'>Last: {$search->last_search}</span></li>";
                            $i++;
                        }
                    } else {
                        echo "<li>No searches found.</li>";
                    }
                    ?>
                </ul>
            </div>
            <div id="tab2" class="tab">
                <h3>Top Searches</h3>
                <ul class="search-list">
                    <?php
                    // Display top searches (5 most searched queries)
                    $top_searches = $wpdb->get_results("
                        SELECT query, COUNT(query) AS search_count 
                        FROM $table_name 
                        GROUP BY query 
                        ORDER BY search_count DESC 
                        LIMIT 5
                    ");

                    if ($top_searches) {
                        $i = 1;
                        foreach ($top_searches as $search) {
                            echo "<li>{$i}. {$search->query} <span class='count'>({$search->search_count} times)</span></li>";
                            $i++;
                        }
                    } else {
                        echo "<li>No searches found.</li>";
                    }
                    ?>
                </ul>
            </div>
        </div>
    </div>

    <style>
        .tabs {
            width: 100%;
            display: inline-block;
        }
        .tab-links {
            margin-bottom: 10px;
        }
        .tab-links:after {
            display: block;
            clear: both;
            content: '';
        }
        .tab-links li {
            margin: 0px 5px;
            float: left;
            list-style: none;
        }
        .tab-links a {
            padding: 10px 15px;
            display: inline-block;
            border-radius: 3px 3px 0px 0px;
            background: #0085ba;
            font-size: 14px;
            font-weight: 600;
            color: white;
            text-transform: uppercase;
            transition: all linear 0.15s;
        }
        .tab-links a:hover {
            background: #006ba1;
        }
        .tab-links li.active a {
            background: #005a8c;
        }
        .tab-content {
            padding: 20px;
            border: 1px solid #ddd;
            border-radius: 0 3px 3px 3px;
            background: #fff;
        }
        .tab {
            display: none;
        }
        .tab.active {
            display: block;
        }
        .search-list {
            list-style-type: none;
            padding: 0;
        }
        .search-list li {
            padding: 10px 0;
            border-bottom: 1px solid #eee;
            font-size: 16px;
        }
        .search-list li:last-child {
            border-bottom: none;
        }
        .search-list .date, .search-list .count {
            float: right;
            color: #666;
            font-size: 14px;
        }
        .tablenav {
            text-align: center;
            margin-top: 20px;
        }
        .tablenav .tablenav-pages {
            display: inline-block;
        }
        .page-numbers {
            margin: 0 5px;
            padding: 3px 10px;
            background: #f1f1f1;
            border: 1px solid #ccc;
            text-decoration: none;
            color: #0073aa;
        }
        .page-numbers.current {
            background: #0073aa;
            color: white;
        }
    </style>

    <script>
        document.querySelectorAll('.tab-links a').forEach(link => {
            link.addEventListener('click', function(e) {
                e.preventDefault();
                let tabId = this.getAttribute('href');
                
                document.querySelectorAll('.tab').forEach(tab => tab.classList.remove('active'));
                document.querySelector(tabId).classList.add('active');
                
                document.querySelectorAll('.tab-links li').forEach(li => li.classList.remove('active'));
                this.parentElement.classList.add('active');
            });
        });
    </script>
    <?php
}

// Create table for search data
register_activation_hook(__FILE__, 'create_searches_table');
function create_searches_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'searches';

    $charset_collate = $wpdb->get_charset_collate();
    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        query text NOT NULL,
        date datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

// Hook to save search queries (this example assumes a search is submitted via GET with 's')
add_action('template_redirect', 'track_search_queries');
function track_search_queries() {
    if (is_search() && !empty($_GET['s'])) {
        global $wpdb;
        $table_name = $wpdb->prefix . 'searches';
        $wpdb->insert(
            $table_name,
            array(
                'query' => sanitize_text_field($_GET['s']),
                'date' => current_time('mysql')
            )
        );
    }
}
